@@ -8,7 +8,7 @@ else:
 
 from django.core.management import call_command
 
-from django_extensions.tests.models import Name, Note, Person
+from django_extensions.tests.testapp.models import Name, Note, Person
 from django_extensions.tests.fields import FieldTestCase
 
 
@@ -31,7 +31,7 @@ class DumpScriptTests(FieldTestCase):
         # lame test...does it run?
         n = Name(name='Gabriel')
         n.save()
-        call_command('dumpscript', 'tests')
+        call_command('dumpscript', 'django_extensions')
         self.assertTrue('Gabriel' in sys.stdout.getvalue())
 
     #----------------------------------------------------------------------
@@ -41,7 +41,7 @@ class DumpScriptTests(FieldTestCase):
         n = Name(name='Mike')
         n.save()
         tmp_out = six.StringIO()
-        call_command('dumpscript', 'tests', stdout=tmp_out)
+        call_command('dumpscript', 'django_extensions', stdout=tmp_out)
         self.assertTrue('Mike' in tmp_out.getvalue())  # script should go to tmp_out
         self.assertEqual(0, len(sys.stdout.getvalue()))  # there should not be any output to sys.stdout
         tmp_out.close()
@@ -53,7 +53,7 @@ class DumpScriptTests(FieldTestCase):
         n.save()
         tmp_err = six.StringIO()
         sys.stderr = six.StringIO()
-        call_command('dumpscript', 'tests', stderr=tmp_err)
+        call_command('dumpscript', 'django_extensions', stderr=tmp_err)
         self.assertTrue('Fred' in sys.stdout.getvalue())  # script should still go to stdout
         self.assertTrue('Name' in tmp_err.getvalue())  # error output should go to tmp_err
         self.assertEqual(0, len(sys.stderr.getvalue()))  # there should not be any output to sys.stderr
@@ -76,7 +76,7 @@ class DumpScriptTests(FieldTestCase):
         note2.save()
         p2.notes.add(note1, note2)
         tmp_out = six.StringIO()
-        call_command('dumpscript', 'tests', stdout=tmp_out)
+        call_command('dumpscript', 'django_extensions', stdout=tmp_out)
         ast_syntax_tree = compiler.parse(tmp_out.getvalue())
         if hasattr(ast_syntax_tree, 'body'):
             self.assertTrue(len(ast_syntax_tree.body) > 1)
